@@ -761,17 +761,15 @@ static int ccs_new_open_permission(struct file *filp)
  * ccs_path_perm - Check permission for "unlink", "rmdir", "truncate", "symlink", "getattr", "chroot" and "unmount".
  *
  * @operation: Type of operation.
- * @dir:       Pointer to "struct inode". Maybe NULL.
  * @dentry:    Pointer to "struct dentry".
  * @mnt:       Pointer to "struct vfsmount". Maybe NULL.
- * @target:    Symlink's target if @operation is CCS_TYPE_SYMLINK.
+ * @target:    Symlink's target if @operation is CCS_TYPE_SYMLINK,
  *             NULL otherwise.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int ccs_path_perm(const u8 operation, struct inode *dir,
-			 struct dentry *dentry, struct vfsmount *mnt,
-			 const char *target)
+static int ccs_path_perm(const u8 operation, struct dentry *dentry,
+			 struct vfsmount *mnt, const char *target)
 {
 	struct ccs_request_info r;
 	struct ccs_obj_info obj = {
@@ -822,7 +820,6 @@ out:
  * ccs_mkdev_perm - Check permission for "mkblock" and "mkchar".
  *
  * @operation: Type of operation. (CCS_TYPE_MKCHAR or CCS_TYPE_MKBLOCK)
- * @dir:       Pointer to "struct inode".
  * @dentry:    Pointer to "struct dentry".
  * @mnt:       Pointer to "struct vfsmount". Maybe NULL.
  * @mode:      Create mode.
@@ -830,9 +827,9 @@ out:
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int ccs_mkdev_perm(const u8 operation, struct inode *dir,
-			  struct dentry *dentry, struct vfsmount *mnt,
-			  const unsigned int mode, unsigned int dev)
+static int ccs_mkdev_perm(const u8 operation, struct dentry *dentry,
+			  struct vfsmount *mnt, const unsigned int mode,
+			  unsigned int dev)
 {
 	struct ccs_request_info r;
 	struct ccs_obj_info obj = {
@@ -880,18 +877,15 @@ out:
  * ccs_path2_perm - Check permission for "rename", "link" and "pivot_root".
  *
  * @operation: Type of operation.
- * @dir1:      Pointer to "struct inode". Maybe NULL.
  * @dentry1:   Pointer to "struct dentry".
  * @mnt1:      Pointer to "struct vfsmount". Maybe NULL.
- * @dir2:      Pointer to "struct inode". Maybe NULL.
  * @dentry2:   Pointer to "struct dentry".
  * @mnt2:      Pointer to "struct vfsmount". Maybe NULL.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int ccs_path2_perm(const u8 operation, struct inode *dir1,
-			  struct dentry *dentry1, struct vfsmount *mnt1,
-			  struct inode *dir2, struct dentry *dentry2,
+static int ccs_path2_perm(const u8 operation, struct dentry *dentry1,
+			  struct vfsmount *mnt1, struct dentry *dentry2,
 			  struct vfsmount *mnt2)
 {
 	struct ccs_request_info r;
@@ -1023,16 +1017,14 @@ static int ccs_update_path_number_acl(const u8 perm,
  * ccs_path_number_perm - Check permission for "create", "mkdir", "mkfifo", "mksock", "ioctl", "chmod", "chown", "chgrp".
  *
  * @type:   Type of operation.
- * @dir:    Pointer to "struct inode". Maybe NULL.
  * @dentry: Pointer to "struct dentry".
  * @vfsmnt: Pointer to "struct vfsmount". Maybe NULL.
  * @number: Number.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int ccs_path_number_perm(const u8 type, struct inode *dir,
-				struct dentry *dentry, struct vfsmount *vfsmnt,
-				unsigned long number)
+static int ccs_path_number_perm(const u8 type, struct dentry *dentry,
+				struct vfsmount *vfsmnt, unsigned long number)
 {
 	struct ccs_request_info r;
 	struct ccs_obj_info obj = {
@@ -1081,7 +1073,7 @@ out:
 static int __ccs_ioctl_permission(struct file *filp, unsigned int cmd,
 				  unsigned long arg)
 {
-	return ccs_path_number_perm(CCS_TYPE_IOCTL, NULL, filp->f_dentry,
+	return ccs_path_number_perm(CCS_TYPE_IOCTL, filp->f_dentry,
 				    filp->f_vfsmnt, cmd);
 }
 
@@ -1099,7 +1091,7 @@ static int __ccs_chmod_permission(struct dentry *dentry,
 {
 	if (mode == (mode_t) -1)
 		return 0;
-	return ccs_path_number_perm(CCS_TYPE_CHMOD, NULL, dentry, vfsmnt,
+	return ccs_path_number_perm(CCS_TYPE_CHMOD, dentry, vfsmnt,
 				    mode & S_IALLUGO);
 }
 
@@ -1121,11 +1113,11 @@ static int __ccs_chown_permission(struct dentry *dentry,
 	if (user == (uid_t) -1 && group == (gid_t) -1)
 		return 0;
 	if (user != (uid_t) -1)
-		error = ccs_path_number_perm(CCS_TYPE_CHOWN, NULL, dentry,
-					     vfsmnt, user);
+		error = ccs_path_number_perm(CCS_TYPE_CHOWN, dentry, vfsmnt,
+					     user);
 	if (!error && group != (gid_t) -1)
-		error = ccs_path_number_perm(CCS_TYPE_CHGRP, NULL, dentry,
-					     vfsmnt, group);
+		error = ccs_path_number_perm(CCS_TYPE_CHGRP, dentry, vfsmnt,
+					     group);
 	return error;
 }
 
@@ -1166,9 +1158,8 @@ static int __ccs_fcntl_permission(struct file *file, unsigned int cmd,
 static int __ccs_pivot_root_permission(struct path *old_path,
 				       struct path *new_path)
 {
-	return ccs_path2_perm(CCS_TYPE_PIVOT_ROOT, NULL, new_path->dentry,
-			      new_path->mnt, NULL, old_path->dentry,
-			      old_path->mnt);
+	return ccs_path2_perm(CCS_TYPE_PIVOT_ROOT, new_path->dentry,
+			      new_path->mnt, old_path->dentry, old_path->mnt);
 }
 
 /**
@@ -1180,8 +1171,7 @@ static int __ccs_pivot_root_permission(struct path *old_path,
  */
 static int __ccs_chroot_permission(struct path *path)
 {
-	return ccs_path_perm(CCS_TYPE_CHROOT, NULL, path->dentry, path->mnt,
-			     NULL);
+	return ccs_path_perm(CCS_TYPE_CHROOT, path->dentry, path->mnt, NULL);
 }
 
 /**
@@ -1194,7 +1184,7 @@ static int __ccs_chroot_permission(struct path *path)
  */
 static int __ccs_umount_permission(struct vfsmount *mnt, int flags)
 {
-	return ccs_path_perm(CCS_TYPE_UMOUNT, NULL, mnt->mnt_root, mnt, NULL);
+	return ccs_path_perm(CCS_TYPE_UMOUNT, mnt->mnt_root, mnt, NULL);
 }
 
 /**
@@ -1203,6 +1193,8 @@ static int __ccs_umount_permission(struct vfsmount *mnt, int flags)
  * @param: Pointer to "struct ccs_acl_param".
  *
  * Returns 0 on success, negative value otherwise.
+ *
+ * Caller holds ccs_read_lock().
  */
 int ccs_write_file(struct ccs_acl_param *param)
 {
@@ -1238,7 +1230,6 @@ int ccs_write_file(struct ccs_acl_param *param)
 /**
  * __ccs_mknod_permission - Check permission for vfs_mknod().
  *
- * @dir:    Pointer to "struct inode".
  * @dentry: Pointer to "struct dentry".
  * @mnt:    Pointer to "struct vfsmount". Maybe NULL.
  * @mode:   Device type and permission.
@@ -1246,32 +1237,31 @@ int ccs_write_file(struct ccs_acl_param *param)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_mknod_permission(struct inode *dir, struct dentry *dentry,
-				  struct vfsmount *mnt,
+static int __ccs_mknod_permission(struct dentry *dentry, struct vfsmount *mnt,
 				  const unsigned int mode, unsigned int dev)
 {
 	int error = 0;
 	const unsigned int perm = mode & S_IALLUGO;
 	switch (mode & S_IFMT) {
 	case S_IFCHR:
-		error = ccs_mkdev_perm(CCS_TYPE_MKCHAR, dir, dentry, mnt, perm,
+		error = ccs_mkdev_perm(CCS_TYPE_MKCHAR, dentry, mnt, perm,
 				       dev);
 		break;
 	case S_IFBLK:
-		error = ccs_mkdev_perm(CCS_TYPE_MKBLOCK, dir, dentry, mnt,
-				       perm, dev);
+		error = ccs_mkdev_perm(CCS_TYPE_MKBLOCK, dentry, mnt, perm,
+				       dev);
 		break;
 	case S_IFIFO:
-		error = ccs_path_number_perm(CCS_TYPE_MKFIFO, dir, dentry, mnt,
+		error = ccs_path_number_perm(CCS_TYPE_MKFIFO, dentry, mnt,
 					     perm);
 		break;
 	case S_IFSOCK:
-		error = ccs_path_number_perm(CCS_TYPE_MKSOCK, dir, dentry, mnt,
+		error = ccs_path_number_perm(CCS_TYPE_MKSOCK, dentry, mnt,
 					     perm);
 		break;
 	case 0:
 	case S_IFREG:
-		error = ccs_path_number_perm(CCS_TYPE_CREATE, dir, dentry, mnt,
+		error = ccs_path_number_perm(CCS_TYPE_CREATE, dentry, mnt,
 					     perm);
 		break;
 	}
@@ -1281,47 +1271,42 @@ static int __ccs_mknod_permission(struct inode *dir, struct dentry *dentry,
 /**
  * __ccs_mkdir_permission - Check permission for vfs_mkdir().
  *
- * @dir:    Pointer to "struct inode".
  * @dentry: Pointer to "struct dentry".
  * @mnt:    Pointer to "struct vfsmount". Maybe NULL.
  * @mode:   Create mode.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_mkdir_permission(struct inode *dir, struct dentry *dentry,
-				  struct vfsmount *mnt, unsigned int mode)
+static int __ccs_mkdir_permission(struct dentry *dentry, struct vfsmount *mnt,
+				  unsigned int mode)
 {
-	return ccs_path_number_perm(CCS_TYPE_MKDIR, dir, dentry, mnt, mode);
+	return ccs_path_number_perm(CCS_TYPE_MKDIR, dentry, mnt, mode);
 }
 
 /**
  * __ccs_rmdir_permission - Check permission for vfs_rmdir().
  *
- * @dir:    Pointer to "struct inode".
  * @dentry: Pointer to "struct dentry".
  * @mnt:    Pointer to "struct vfsmount". Maybe NULL.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_rmdir_permission(struct inode *dir, struct dentry *dentry,
-				  struct vfsmount *mnt)
+static int __ccs_rmdir_permission(struct dentry *dentry, struct vfsmount *mnt)
 {
-	return ccs_path_perm(CCS_TYPE_RMDIR, dir, dentry, mnt, NULL);
+	return ccs_path_perm(CCS_TYPE_RMDIR, dentry, mnt, NULL);
 }
 
 /**
  * __ccs_unlink_permission - Check permission for vfs_unlink().
  *
- * @dir:    Pointer to "struct inode".
  * @dentry: Pointer to "struct dentry".
  * @mnt:    Pointer to "struct vfsmount". Maybe NULL.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_unlink_permission(struct inode *dir, struct dentry *dentry,
-				   struct vfsmount *mnt)
+static int __ccs_unlink_permission(struct dentry *dentry, struct vfsmount *mnt)
 {
-	return ccs_path_perm(CCS_TYPE_UNLINK, dir, dentry, mnt, NULL);
+	return ccs_path_perm(CCS_TYPE_UNLINK, dentry, mnt, NULL);
 }
 
 /**
@@ -1335,23 +1320,22 @@ static int __ccs_unlink_permission(struct inode *dir, struct dentry *dentry,
 static int __ccs_getattr_permission(struct vfsmount *mnt,
 				    struct dentry *dentry)
 {
-	return ccs_path_perm(CCS_TYPE_GETATTR, NULL, dentry, mnt, NULL);
+	return ccs_path_perm(CCS_TYPE_GETATTR, dentry, mnt, NULL);
 }
 
 /**
  * __ccs_symlink_permission - Check permission for vfs_symlink().
  *
- * @dir:    Pointer to "struct inode".
  * @dentry: Pointer to "struct dentry".
  * @mnt:    Pointer to "struct vfsmount". Maybe NULL.
  * @from:   Content of symlink.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_symlink_permission(struct inode *dir, struct dentry *dentry,
+static int __ccs_symlink_permission(struct dentry *dentry,
 				    struct vfsmount *mnt, const char *from)
 {
-	return ccs_path_perm(CCS_TYPE_SYMLINK, dir, dentry, mnt, from);
+	return ccs_path_perm(CCS_TYPE_SYMLINK, dentry, mnt, from);
 }
 
 /**
@@ -1365,47 +1349,40 @@ static int __ccs_symlink_permission(struct inode *dir, struct dentry *dentry,
 static int __ccs_truncate_permission(struct dentry *dentry,
 				     struct vfsmount *mnt)
 {
-	return ccs_path_perm(CCS_TYPE_TRUNCATE, NULL, dentry, mnt, NULL);
+	return ccs_path_perm(CCS_TYPE_TRUNCATE, dentry, mnt, NULL);
 }
 
 /**
  * __ccs_rename_permission - Check permission for vfs_rename().
  *
- * @old_dir:    Pointer to "struct inode".
  * @old_dentry: Pointer to "struct dentry".
- * @new_dir:    Pointer to "struct inode".
  * @new_dentry: Pointer to "struct dentry".
  * @mnt:        Pointer to "struct vfsmount". Maybe NULL.
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_rename_permission(struct inode *old_dir,
-				   struct dentry *old_dentry,
-				   struct inode *new_dir,
+static int __ccs_rename_permission(struct dentry *old_dentry,
 				   struct dentry *new_dentry,
 				   struct vfsmount *mnt)
 {
-	return ccs_path2_perm(CCS_TYPE_RENAME, old_dir, old_dentry, mnt,
-			      new_dir, new_dentry, mnt);
+	return ccs_path2_perm(CCS_TYPE_RENAME, old_dentry, mnt, new_dentry,
+			      mnt);
 }
 
 /**
  * __ccs_link_permission - Check permission for vfs_link().
  *
  * @old_dentry: Pointer to "struct dentry".
- * @new_dir:    Pointer to "struct inode".
  * @new_dentry: Pointer to "struct dentry".
  * @mnt:        Pointer to "struct vfsmount". Maybe NULL.
  *
  * Returns 0 on success, negative value otherwise.
  */
 static int __ccs_link_permission(struct dentry *old_dentry,
-				 struct inode *new_dir,
 				 struct dentry *new_dentry,
 				 struct vfsmount *mnt)
 {
-	return ccs_path2_perm(CCS_TYPE_LINK, NULL, old_dentry, mnt,
-			      new_dir, new_dentry, mnt);
+	return ccs_path2_perm(CCS_TYPE_LINK, old_dentry, mnt, new_dentry, mnt);
 }
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 30)
