@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/load_policy.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.0+   2010/12/31
+ * Version: 1.8.1   2011/04/01
  */
 
 #include <linux/version.h>
@@ -33,6 +33,8 @@
 
 #include <linux/ccsecurity.h>
 
+#ifndef CONFIG_CCSECURITY_OMIT_USERSPACE_LOADER
+
 /* Path to the policy loader. (default = CONFIG_CCSECURITY_DEFAULT_LOADER) */
 static const char *ccs_loader;
 
@@ -51,6 +53,8 @@ static int __init ccs_loader_setup(char *str)
 
 __setup("CCS_loader=", ccs_loader_setup);
 
+#endif
+
 /**
  * ccs_setup - Set enable/disable upon boot.
  *
@@ -69,6 +73,8 @@ static int __init ccs_setup(char *str)
 
 __setup("ccsecurity=", ccs_setup);
 
+#ifndef CONFIG_CCSECURITY_OMIT_USERSPACE_LOADER
+
 /**
  * ccs_policy_loader_exists - Check whether /sbin/ccs-init exists.
  *
@@ -81,13 +87,14 @@ static _Bool ccs_policy_loader_exists(void)
 	 * exist. If the initrd includes /sbin/init but real-root-dev has not
 	 * mounted on / yet, activating MAC will block the system since
 	 * policies are not loaded yet.
-	 * Thus, let do_execve() call this function everytime.
+	 * Thus, let do_execve() call this function every time.
 	 */
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 28)
 	struct path path;
 	if (!ccs_loader)
 		ccs_loader = CONFIG_CCSECURITY_DEFAULT_LOADER;
-	if (kern_path(ccs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE, &path) == 0) {
+	if (kern_path(ccs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE,
+		      &path) == 0) {
 		path_put(&path);
 		return 1;
 	}
@@ -215,6 +222,8 @@ static void ccs_load_policy(const char *filename)
 		panic("Failed to load policy.");
 }
 
+#endif
+
 /**
  * __ccs_search_binary_handler - Load policy before calling search_binary_handler().
  *
@@ -226,7 +235,9 @@ static void ccs_load_policy(const char *filename)
 static int __ccs_search_binary_handler(struct linux_binprm *bprm,
 				       struct pt_regs *regs)
 {
+#ifndef CONFIG_CCSECURITY_OMIT_USERSPACE_LOADER
 	ccs_load_policy(bprm->filename);
+#endif
 	/*
 	 * ccs_load_policy() executes /sbin/ccs-init if bprm->filename is
 	 * /sbin/init. /sbin/ccs-init executes /etc/ccs/ccs-load-module to
@@ -254,7 +265,9 @@ extern spinlock_t vfsmount_lock;
 
 /* For exporting variables and functions. */
 const struct ccsecurity_exports ccsecurity_exports = {
+#ifndef CONFIG_CCSECURITY_OMIT_USERSPACE_LOADER
 	.load_policy = ccs_load_policy,
+#endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36)
 	.__d_path = __d_path,
 #elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 0)
