@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.1+   2011/04/11
+ * Version: 1.8.1+   2011/05/11
  */
 
 #include "internal.h"
@@ -500,7 +500,7 @@ static void ccs_check_profile(void)
 		panic("Profile version %u is not supported.\n",
 		      ccs_profile_version);
 	}
-	printk(KERN_INFO "CCSecurity: 1.8.1+   2011/04/11\n");
+	printk(KERN_INFO "CCSecurity: 1.8.1+   2011/05/11\n");
 	printk(KERN_INFO "Mandatory Access Control activated.\n");
 }
 
@@ -741,7 +741,7 @@ next:
 				ccs_io_printf(head, "%s=%u ",
 					      ccs_pref_keywords[i],
 					      profile->pref[i]);
-			ccs_set_string(head, " }\n");
+			ccs_set_string(head, "}\n");
 			head->r.step++;
 		}
 		break;
@@ -1018,6 +1018,8 @@ static bool ccs_same_task_acl(const struct ccs_acl_info *a,
  * @param: Pointer to "struct ccs_acl_param".
  *
  * Returns 0 on success, negative value otherwise.
+ *
+ * Caller holds ccs_read_lock().
  */
 static int ccs_write_task(struct ccs_acl_param *param)
 {
@@ -1071,6 +1073,8 @@ static int ccs_write_task(struct ccs_acl_param *param)
  * @is_delete: True if it is a delete request.
  *
  * Returns 0 on success, negative value otherwise.
+ *
+ * Caller holds ccs_read_lock().
  */
 static int ccs_write_domain2(char *data, struct ccs_domain_info *domain,
 			     const bool is_delete)
@@ -1101,6 +1105,36 @@ static int ccs_write_domain2(char *data, struct ccs_domain_info *domain,
 	return -EINVAL;
 }
 
+/**
+ * ccs_delete_domain - Delete a domain.
+ *
+ * @domainname: The name of domain.
+ *
+ * Returns 0.
+ */
+static int ccs_delete_domain(char *domainname)
+{
+	struct ccs_domain_info *domain;
+	struct ccs_path_info name;
+	name.name = domainname;
+	ccs_fill_path_info(&name);
+	if (mutex_lock_interruptible(&ccs_policy_lock))
+		return 0;
+	/* Is there an active domain? */
+	list_for_each_entry_srcu(domain, &ccs_domain_list, list, &ccs_ss) {
+		/* Never delete ccs_kernel_domain. */
+		if (domain == &ccs_kernel_domain)
+			continue;
+		if (domain->is_deleted ||
+		    ccs_pathcmp(domain->domainname, &name))
+			continue;
+		domain->is_deleted = true;
+		break;
+	}
+	mutex_unlock(&ccs_policy_lock);
+	return 0;
+}
+
 /* String table for domain flags. */
 const char * const ccs_dif[CCS_MAX_DOMAIN_INFO_FLAGS] = {
 	[CCS_DIF_QUOTA_WARNED]      = "quota_exceeded\n",
@@ -1113,6 +1147,8 @@ const char * const ccs_dif[CCS_MAX_DOMAIN_INFO_FLAGS] = {
  * @head: Pointer to "struct ccs_io_buffer".
  *
  * Returns 0 on success, negative value otherwise.
+ *
+ * Caller holds ccs_read_lock().
  */
 static int ccs_write_domain(struct ccs_io_buffer *head)
 {
@@ -2367,7 +2403,7 @@ static void ccs_read_query(struct ccs_io_buffer *head)
 		 * can change, but I don't care.
 		 */
 		if (len == ptr->query_len)
-			snprintf(buf, len + 32, "Q%u-%hu\n%s", ptr->serial,
+			snprintf(buf, len + 31, "Q%u-%hu\n%s", ptr->serial,
 				 ptr->retry, ptr->query);
 		break;
 	}
